#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-bash
version:              1.0.41
visibility:           public
id:                   dhall-bash-1.0.41-8tViK0aiFIxAkewZbf2rhB
key:                  dhall-bash-1.0.41-8tViK0aiFIxAkewZbf2rhB
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  786f7e60c8f8f8222ad6da83b98bd7b5
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.41-8tViK0aiFIxAkewZbf2rhB
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-EgjOYzr7OhiJ6ElQLzvC4s
    neat-interpolation-0.5.1.4-BgmTPeCBcWCHekXF7CVWeD
    shell-escape-0.2.0-JHFLkxwbiUI7oM7VdHlBPe text-2.0.2

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

